==> Glossary-0.6.7.tar.gz: Glossary/action.default.php <==
<?php
#-------------------------------------------------------------------------
# Module: Glossary / Dictionary / FAQ module
# Version: 0.6.6, SjG
# http://dev.cmsmadesimple.org/projects/glossary
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2009 by Ted Kulp (ted@cmsmadesimple.org)
# http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

   global $gCms;
   $db = &$this->cms->db;

   $this->SmartyTermList($params,$id,$returnid);
    // Display the populated template
    if (isset($params['template']))
      {
      if (! is_numeric($params['template']))
         {
         $query = "SELECT template_id FROM ".cms_db_prefix().
	        'module_glossary_template WHERE name=?';
	      $dbresult = $db->Execute($query,array($params['template']));
         if ($dbresult !== false && $row = $dbresult->FetchRow())
            {
            $params['template'] = $row['template_id'];
            }
         }
      $str = 'glossary_'.$params['template'];
	  echo $this->ProcessTemplateFromDatabase($str);
      }
    else
      {
      $defaultTemplate = $this->GetPreference('default_template','');
      echo $this->ProcessTemplateFromDatabase('glossary_'.$defaultTemplate);
      }        

# EOF
?>

==> Glossary-1.0.tar.gz: Glossary/action.default.php <==
<?php
#-------------------------------------------------------------------------
# Module: Glossary / Dictionary / FAQ module
# Version: 0.6.6, SjG
# http://dev.cmsmadesimple.org/projects/glossary
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2009 by Ted Kulp (ted@cmsmadesimple.org)
# http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
if( !isset($gCms) ) exit;

// Display the populated template
$template = $this->GetPreference('default_template','');
if (isset($params['template'])) {
  if (! is_numeric($params['template'])) {
    $query = "SELECT template_id FROM ".cms_db_prefix().'module_glossary_template 
              WHERE name=?';
    $dbresult = $db->Execute($query,array($params['template']));
    if ($dbresult !== false && $row = $dbresult->FetchRow()) {
      $params['template'] = $row['template_id'];
    }
  }
  $template = $params['template'];
}
$template = 'glossary_'.$template;

$cache_id = '|ns'.md5(serialize($params));
$compile_id = '';

if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_id) ) {
  $this->SmartyTermList($params,$id,$returnid);
}
echo $smarty->fetch($this->GetDatabaseResource($template),$cache_id,$compile_id);

# EOF
?>
